@@ -4,7 +4,7 @@
     This file is part of Corrade.
 
     Copyright © 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
-                2017, 2018 Vladimír Vondruš <mosra@centrum.cz>
+                2017, 2018, 2019 Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -34,15 +34,6 @@
 namespace Corrade {
 
 #ifdef DOXYGEN_GENERATING_OUTPUT
-/**
-@brief GCC 4.7 compatibility
-
-Defined if compatibility mode for GCC 4.7 is enabled.
-@see @ref building-corrade, @ref corrade-cmake
-*/
-#define CORRADE_GCC47_COMPATIBILITY
-#undef CORRADE_GCC47_COMPATIBILITY
-
 /**
 @brief MSVC 2017 compatibility
 
@@ -81,11 +72,27 @@ Defined if built as static libraries. Default are shared libraries.
 #define CORRADE_BUILD_STATIC
 #undef CORRADE_BUILD_STATIC
 
+/**
+@brief C++ standard version
+
+Expands to `__cplusplus` macro on all sane compilers; on MSVC uses `_MSVC_LANG`
+if defined (since Visual Studio 2015 Update 3), otherwise reports C++11. The
+returned version is:
+
+-   @cpp 201703 @ce when C++17 is used
+-   @cpp 201402 @ce when C++14 is used
+-   @cpp 201103 @ce when C++11 is used
+*/
+#define CORRADE_CXX_STANDARD
+#undef CORRADE_CXX_STANDARD
+
 /**
 @brief Unix target
 
 Defined if the library is built for some Unix flavor (Linux, BSD, macOS, iOS,
-Android...).
+Android...). Note that while the behavior of Emscripten is closely emulating
+Unix systems, `CORRADE_TARGET_UNIX` is not defined there, only
+@ref CORRADE_TARGET_EMSCRIPTEN.
 @see @ref CORRADE_TARGET_APPLE, @ref CORRADE_TARGET_ANDROID, @ref corrade-cmake
 */
 #define CORRADE_TARGET_UNIX
@@ -142,6 +149,8 @@ Defined if the library is built for Windows Store or Phone.
 @brief Emscripten target
 
 Defined if the library is built for [Emscripten](http://kripken.github.io/emscripten-site/).
+Note that while the behavior of Emscripten is closely emulating Unix systems,
+@ref CORRADE_TARGET_UNIX is not defined there, only `CORRADE_TARGET_EMSCRIPTEN`.
 @see @ref building-corrade, @ref corrade-cmake
 */
 #define CORRADE_TARGET_EMSCRIPTEN
@@ -207,7 +216,7 @@ CMake option when building Corrade.
 #undef CORRADE_TESTSUITE_TARGET_XCTEST
 
 /**
-@brief Use ANSI escape sequences for colored Debug output on Windows
+@brief Use ANSI escape sequences for colored debug output on Windows
 
 By default colored output using @ref Corrade::Utility::Debug "Utility::Debug"
 on Windows is done using WINAPI that has a limited functionality, because ANSI
