@@ -4,7 +4,7 @@
     This file is part of Corrade.
 
     Copyright © 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
-                2017, 2018 Vladimír Vondruš <mosra@centrum.cz>
+                2017, 2018, 2019 Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -58,28 +58,7 @@ argument etc.), the parser prints short usage information and exits.
 Contrived example of command-line utility which prints given text given number
 of times, optionally redirecting the output to a file:
 
-@code{.cpp}
-int main(int argc, char** argv) {
-    Arguments args;
-    args.addArgument("text").setHelp("text", "the text to print")
-        .addNamedArgument('n', "repeat").setHelp("repeat", "repeat count")
-        .addBooleanOption('v', "verbose").setHelp("verbose", "log verbosely")
-        .addOption("log", "log.txt").setHelp("log", "save verbose log to given file")
-        .setHelp("Repeats the text given number of times.")
-        .parse(argc, argv);
-
-    std::ofstream logOutput(args.value("log"));
-    for(int i = 0; i < args.value<int>("repeat"); ++i) {
-        if(args.isSet("verbose")) {
-            logOutput << "Printing instance " << i << " of text " << args.value("text");
-        }
-
-        std::cout << args.value("text");
-    }
-
-    return 0;
-}
-@endcode
+@snippet Utility.cpp Arguments-usage
 
 Upon requesting help, the utility prints the following:
 
@@ -109,23 +88,7 @@ would skip those instead of reporting them as unknown. The prefixed arguments
 are restricted to non-boolean options with long names to keep the usage simple
 both for the application author and users. Example:
 
-@code{.cpp}
-{
-    // the underlying library
-    Arguments args{"formatter"};
-    args.addOption("width", "80").setHelp("width", "number of columns")
-        .addOption("color", "auto").setHelp("color", "output color")
-        .parse(argc, argv);
-}
-
-// the application
-Arguments args;
-args.addArgument("text").setHelp("text", "the text to print")
-    .addNamedArgument('n', "repeat").setHelp("repeat", "repeat count")
-    .addSkippedPrefix("formatter", "formatter options")
-    .setHelp("Repeats the text given number of times.")
-    .parse(argc, argv);
-@endcode
+@snippet Utility.cpp Arguments-delegating
 
 The application can be then called like the following, the prefixed and
 unprefixed options and named arguments can be mixed without restriction:
@@ -165,6 +128,11 @@ Arguments:
   --formatter-color COLOR  output color
                            (default: auto)
 @endcode
+
+Boolean options would cause parsing ambiguity so they are not allowed, but you
+can work around the limitation like this, for example:
+
+@snippet Utility.cpp Arguments-delegating-bool
 */
 class CORRADE_UTILITY_EXPORT Arguments {
     public:
@@ -197,14 +165,50 @@ class CORRADE_UTILITY_EXPORT Arguments {
          */
         explicit Arguments(const std::string& prefix);
 
+        /** @brief Copying is not allowed */
+        Arguments(const Arguments&) = delete;
+
+        /**
+         * @brief Move constructor
+         *
+         * A moved-out instance behaves the same as newly created instance.
+         */
+        Arguments(Arguments&& other) noexcept;
+
+        /** @brief Copying is not allowed */
+        Arguments& operator=(const Arguments&) = delete;
+
+        /**
+         * @brief Move assignment
+         *
+         * Swaps contents of the two instances.
+         */
+        Arguments& operator=(Arguments&& other) noexcept;
+
         ~Arguments();
 
+        /**
+         * @brief Argument prefix
+         *
+         * If the class was instantiated with @ref Arguments(const std::string&),
+         * returns the specified prefix. Otherwise returns empty string.
+         */
+        std::string prefix() const;
+
+        /**
+         * @brief Whether the arguments were successfully parsed
+         *
+         * Returns @cpp true @ce if @ref parse() was successfully called,
+         * @cpp false @ce otherwise.
+         */
+        bool isParsed() const { return _isParsed; }
+
         /**
          * @brief Add mandatory argument
          *
          * After calling @cpp addArgument("argument") @ce the argument will be
-         * displayed in argument list like the following. Call
-         * @ref setHelpKey() to change the displayed key:
+         * displayed in argument list like the following. Call @ref setHelp()
+         * to change the displayed key:
          *
          * @code{.shell-session}
          * Usage:
@@ -228,7 +232,7 @@ class CORRADE_UTILITY_EXPORT Arguments {
          *
          * After calling @cpp addNamedArgument('a', "argument") @ce the
          * argument will be displayed in help text like the following. Argument
-         * value is just uppercased key value, call @ref setHelpKey() to change
+         * value is just uppercased key value, call @ref setHelp() to change
          * it:
          *
          * @code{.shell-session}
@@ -236,7 +240,7 @@ class CORRADE_UTILITY_EXPORT Arguments {
          *   ./app -a|--argument ARGUMENT
          *
          * Arguments:
-         *   --a, --argument   help text
+         *   -a, --argument    help text
          * @endcode
          *
          * If no help text is set, the argument is not displayed in argument
@@ -274,7 +278,7 @@ class CORRADE_UTILITY_EXPORT Arguments {
          *
          * After calling @cpp addOption('o', "option") @ce the option will be
          * displayed in help text like the following. Option value is just
-         * uppercased key value, call @ref setHelpKey() to change it:
+         * uppercased key value, call @ref setHelp() to change it:
          *
          * @code{.shell-session}
          * Usage:
@@ -334,9 +338,9 @@ class CORRADE_UTILITY_EXPORT Arguments {
          *   -o, --option      help text
          * @endcode
          *
-         * Option presence can be queried with @ref isSet(), @ref setHelpKey()
-         * cannot be used with boolean options. Option for getting help (`-h`,
-         * `--help`) is added automatically.
+         * Option presence can be queried with @ref isSet(). Setting displayed
+         * key name in @ref setHelp() is not possible with boolean options.
+         * Option for getting help (`-h`, `--help`) is added automatically.
          *
          * Only non-boolean options are allowed in the prefixed version, use
          * @ref addOption() instead.
@@ -462,13 +466,6 @@ class CORRADE_UTILITY_EXPORT Arguments {
          */
         Arguments& setHelp(const std::string& key, std::string help, std::string helpKey = {});
 
-        #ifdef CORRADE_BUILD_DEPRECATED
-        /** @brief @copybrief setHelp(const std::string&, std::string, std::string)
-         * @deprecated Use @ref setHelp(const std::string&, std::string, std::string) instead.
-         */
-        CORRADE_DEPRECATED("use setHelp() instead") Arguments& setHelpKey(const std::string& key, std::string helpKey);
-        #endif
-
         /**
          * @brief Parse the arguments and exit on failure
          *
@@ -532,11 +529,10 @@ class CORRADE_UTILITY_EXPORT Arguments {
          * @param key       Long argument or option key
          * @param flags     Configuration value flags
          *
-         * Expects that the key exists. Use @ref isSet() for boolean options.
-         * If the arguments weren't parsed yet, returns empty string or
-         * default-constructed value. If @p T is not @ref std::string, uses
-         * @ref ConfigurationValue::fromString() to convert the value to given
-         * type.
+         * Expects that the key exists and @ref parse() was successful. Use
+         * @ref isSet() for boolean options. If @p T is not @ref std::string,
+         * uses @ref ConfigurationValue::fromString() to convert the value to
+         * given type.
          */
         template<class T = std::string> T value(const std::string& key, ConfigurationValueFlags flags = {}) const;
 
@@ -544,9 +540,8 @@ class CORRADE_UTILITY_EXPORT Arguments {
          * @brief Whether boolean option is set
          * @param key   Long option key
          *
-         * Expects that the option exists and is boolean. Help option (`-h`,
-         * `--help`) is present by default. If the arguments weren't parsed
-         * yet, returns false.
+         * Expects that the option exists, is boolean and @ref parse() was
+         * successful. Help option (`-h`, `--help`) is present by default.
          * @see @ref value()
          */
         bool isSet(const std::string& key) const;
@@ -566,6 +561,7 @@ class CORRADE_UTILITY_EXPORT Arguments {
 
         std::string valueInternal(const std::string& key) const;
 
+        bool _isParsed{false};
         std::string _prefix;
         std::string _command;
         std::string _help;
